summaryrefslogtreecommitdiffstats
path: root/kicker/kicker/ui
diff options
context:
space:
mode:
Diffstat (limited to 'kicker/kicker/ui')
-rw-r--r--kicker/kicker/ui/addapplet.cpp8
-rw-r--r--kicker/kicker/ui/addappletvisualfeedback.cpp8
-rw-r--r--kicker/kicker/ui/appletitem.ui12
-rw-r--r--kicker/kicker/ui/appletop_mnu.cpp10
-rw-r--r--kicker/kicker/ui/appletview.ui4
-rw-r--r--kicker/kicker/ui/browser_dlg.cpp2
-rw-r--r--kicker/kicker/ui/browser_mnu.cpp2
-rw-r--r--kicker/kicker/ui/clicklineedit.cpp8
-rw-r--r--kicker/kicker/ui/client_mnu.cpp2
-rw-r--r--kicker/kicker/ui/exe_dlg.cpp4
-rw-r--r--kicker/kicker/ui/extensionop_mnu.cpp2
-rw-r--r--kicker/kicker/ui/flipscrollview.cpp8
-rw-r--r--kicker/kicker/ui/hidebutton.cpp14
-rw-r--r--kicker/kicker/ui/itemview.cpp30
-rw-r--r--kicker/kicker/ui/itemview.h2
-rw-r--r--kicker/kicker/ui/k_mnu.cpp24
-rw-r--r--kicker/kicker/ui/k_mnu.h2
-rw-r--r--kicker/kicker/ui/k_mnu_stub.cpp6
-rw-r--r--kicker/kicker/ui/k_mnu_stub.h2
-rw-r--r--kicker/kicker/ui/k_new_mnu.cpp98
-rw-r--r--kicker/kicker/ui/k_new_mnu.h6
-rw-r--r--kicker/kicker/ui/kickoff_bar.cpp20
-rw-r--r--kicker/kicker/ui/kickoff_bar.h2
-rw-r--r--kicker/kicker/ui/kmenuitembase.ui12
-rw-r--r--kicker/kicker/ui/nonKDEButtonSettings.ui8
-rw-r--r--kicker/kicker/ui/popupmenutitle.h4
-rw-r--r--kicker/kicker/ui/removeapplet_mnu.cpp4
-rw-r--r--kicker/kicker/ui/removebutton_mnu.cpp4
-rw-r--r--kicker/kicker/ui/removeextension_mnu.cpp4
-rw-r--r--kicker/kicker/ui/service_mnu.cpp8
30 files changed, 160 insertions, 160 deletions
diff --git a/kicker/kicker/ui/addapplet.cpp b/kicker/kicker/ui/addapplet.cpp
index 163a4ae9d..c5fc8d84f 100644
--- a/kicker/kicker/ui/addapplet.cpp
+++ b/kicker/kicker/ui/addapplet.cpp
@@ -27,9 +27,9 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#include <tqdir.h>
#include <tqframe.h>
#include <tqlabel.h>
-#include <tqlayout.h>
+#include <layout.h>
#include <tqlineedit.h>
-#include <tqpalette.h>
+#include <palette.h>
#include <tqscrollview.h>
#include <tqtimer.h>
#include <tqsizepolicy.h>
@@ -291,7 +291,7 @@ void AddAppletDialog::resizeAppletView()
{
m_appletBox->layout()->activate();
w = v->visibleWidth();
- h = m_appletBox->tqlayout()->tqminimumSize().height();
+ h = m_appletBox->layout()->minimumSize().height();
v->resizeContents(w, QMAX(h, v->visibleHeight()));
if (w == m_appletBox->width() && h == m_appletBox->height())
break;
@@ -456,7 +456,7 @@ void AddAppletDialog::addApplet(AppletWidget* applet)
if (appletContainer)
{
ExtensionContainer* ec =
- dynamic_cast<ExtensionContainer*>(m_containerArea->tqtopLevelWidget());
+ dynamic_cast<ExtensionContainer*>(m_containerArea->topLevelWidget());
if (ec)
{
diff --git a/kicker/kicker/ui/addappletvisualfeedback.cpp b/kicker/kicker/ui/addappletvisualfeedback.cpp
index 7f4f90676..e5fa5672c 100644
--- a/kicker/kicker/ui/addappletvisualfeedback.cpp
+++ b/kicker/kicker/ui/addappletvisualfeedback.cpp
@@ -157,7 +157,7 @@ void AddAppletVisualFeedback::displayInternal()
// draw background
TQPainter bufferPainter(&m_pixmap);
bufferPainter.setPen(Qt::black);
- bufferPainter.setBrush(tqcolorGroup().background());
+ bufferPainter.setBrush(colorGroup().background());
bufferPainter.drawRoundRect(0, 0, width, height,
1600 / width, 1600 / height);
@@ -175,14 +175,14 @@ void AddAppletVisualFeedback::displayInternal()
int textY = (height - textRect.height()) / 2;
// draw text shadow
- TQColorGroup cg = tqcolorGroup();
+ TQColorGroup cg = colorGroup();
cg.setColor(TQColorGroup::Text, cg.background().dark(115));
int shadowOffset = TQApplication::reverseLayout() ? -1 : 1;
m_richText->draw(&bufferPainter, 5 + textX + shadowOffset,
textY + 1, TQRect(), cg);
// draw text
- cg = tqcolorGroup();
+ cg = colorGroup();
m_richText->draw(&bufferPainter, 5 + textX, textY, rect(), cg);
}
}
@@ -225,7 +225,7 @@ void AddAppletVisualFeedback::swoopCloser()
void AddAppletVisualFeedback::internalUpdate()
{
m_dirty = true;
- tqrepaint(false);
+ repaint(false);
}
#include "addappletvisualfeedback.moc"
diff --git a/kicker/kicker/ui/appletitem.ui b/kicker/kicker/ui/appletitem.ui
index dc6faab50..46e62b342 100644
--- a/kicker/kicker/ui/appletitem.ui
+++ b/kicker/kicker/ui/appletitem.ui
@@ -20,13 +20,13 @@
<verstretch>0</verstretch>
</sizepolicy>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>0</width>
<height>0</height>
</size>
</property>
- <property name="tqmaximumSize">
+ <property name="maximumSize">
<size>
<width>32767</width>
<height>80</height>
@@ -65,7 +65,7 @@
<property name="textFormat">
<enum>RichText</enum>
</property>
- <property name="tqalignment">
+ <property name="alignment">
<set>WordBreak|AlignTop</set>
</property>
</widget>
@@ -87,7 +87,7 @@
<property name="textFormat">
<enum>RichText</enum>
</property>
- <property name="tqalignment">
+ <property name="alignment">
<set>WordBreak|AlignTop</set>
</property>
</widget>
@@ -105,7 +105,7 @@
<property name="name">
<cstring>itemPixmap</cstring>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>64</width>
<height>64</height>
@@ -117,7 +117,7 @@
<property name="text">
<string></string>
</property>
- <property name="tqalignment">
+ <property name="alignment">
<set>AlignTop</set>
</property>
</widget>
diff --git a/kicker/kicker/ui/appletop_mnu.cpp b/kicker/kicker/ui/appletop_mnu.cpp
index 925571e61..1ef72d2c7 100644
--- a/kicker/kicker/ui/appletop_mnu.cpp
+++ b/kicker/kicker/ui/appletop_mnu.cpp
@@ -52,7 +52,7 @@ PanelAppletOpMenu::PanelAppletOpMenu(int actions, TQPopupMenu *opMenu, const TQP
TQString text = isButton ? (isMenu ? i18n("&Move %1 Menu") :
i18n("&Move %1 Button")) :
i18n("&Move %1");
- insertItem(SmallIcon("move"), text.tqarg(titleText), Move);
+ insertItem(SmallIcon("move"), text.arg(titleText), Move);
// we look for a container area to see if we can add containers
// this is part of the kiosk support in kicker, allowing
@@ -76,7 +76,7 @@ PanelAppletOpMenu::PanelAppletOpMenu(int actions, TQPopupMenu *opMenu, const TQP
text = isButton ? (isMenu ? i18n("&Remove %1 Menu") :
i18n("&Remove %1 Button")) :
i18n("&Remove %1");
- insertItem(SmallIcon("remove"), text.tqarg(titleText), Remove);
+ insertItem(SmallIcon("remove"), text.arg(titleText), Remove);
needSeparator = true;
}
}
@@ -103,7 +103,7 @@ PanelAppletOpMenu::PanelAppletOpMenu(int actions, TQPopupMenu *opMenu, const TQP
KIcon::Small, 0,
KIcon::DefaultState,
0, true));
- insertItem(iconPix, i18n("&About %1").tqarg( titleText ), About);
+ insertItem(iconPix, i18n("&About %1").arg( titleText ), About);
needSeparator = !(actions & KPanelApplet::Help);
}
@@ -123,12 +123,12 @@ PanelAppletOpMenu::PanelAppletOpMenu(int actions, TQPopupMenu *opMenu, const TQP
if (isButton)
{
insertItem(SmallIcon("configure"),
- i18n("&Configure %1 Button...").tqarg(titleText), Preferences);
+ i18n("&Configure %1 Button...").arg(titleText), Preferences);
}
else
{
insertItem(SmallIcon("configure"),
- i18n("&Configure %1...").tqarg(titleText), Preferences);
+ i18n("&Configure %1...").arg(titleText), Preferences);
}
needSeparator = true;
}
diff --git a/kicker/kicker/ui/appletview.ui b/kicker/kicker/ui/appletview.ui
index 4ba0f38e8..f5a32651b 100644
--- a/kicker/kicker/ui/appletview.ui
+++ b/kicker/kicker/ui/appletview.ui
@@ -110,7 +110,7 @@
<verstretch>1</verstretch>
</sizepolicy>
</property>
- <property name="tqmaximumSize">
+ <property name="maximumSize">
<size>
<width>32767</width>
<height>32767</height>
@@ -141,7 +141,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>284</width>
<height>20</height>
diff --git a/kicker/kicker/ui/browser_dlg.cpp b/kicker/kicker/ui/browser_dlg.cpp
index 01e72d9ee..2ca76cc3e 100644
--- a/kicker/kicker/ui/browser_dlg.cpp
+++ b/kicker/kicker/ui/browser_dlg.cpp
@@ -22,7 +22,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
******************************************************************/
#include <tqlabel.h>
-#include <tqlayout.h>
+#include <layout.h>
#include <tqvbox.h>
#include <kglobal.h>
diff --git a/kicker/kicker/ui/browser_mnu.cpp b/kicker/kicker/ui/browser_mnu.cpp
index ee62791e9..4998fc5cf 100644
--- a/kicker/kicker/ui/browser_mnu.cpp
+++ b/kicker/kicker/ui/browser_mnu.cpp
@@ -429,7 +429,7 @@ void PanelBrowserMenu::dragMoveEvent(TQDragMoveEvent *ev)
void PanelBrowserMenu::dropEvent( TQDropEvent *ev )
{
KURL u( path() );
- KFileItem item( u, TQString::tqfromLatin1( "inode/directory" ), KFileItem::Unknown );
+ KFileItem item( u, TQString::fromLatin1( "inode/directory" ), KFileItem::Unknown );
KonqOperations::doDrop( &item, u, ev, this );
KPanelMenu::dropEvent(ev);
// ### TODO: Update list
diff --git a/kicker/kicker/ui/clicklineedit.cpp b/kicker/kicker/ui/clicklineedit.cpp
index 1793d97b3..c5499f217 100644
--- a/kicker/kicker/ui/clicklineedit.cpp
+++ b/kicker/kicker/ui/clicklineedit.cpp
@@ -39,13 +39,13 @@ ClickLineEdit::~ClickLineEdit() {}
void ClickLineEdit::setClickMessage( const TQString &msg )
{
mClickMessage = msg;
- tqrepaint();
+ repaint();
}
void ClickLineEdit::setText( const TQString &txt )
{
mDrawClickMsg = txt.isEmpty();
- tqrepaint();
+ repaint();
KLineEdit::setText( txt );
}
@@ -67,7 +67,7 @@ void ClickLineEdit::focusInEvent( TQFocusEvent *ev )
if ( mDrawClickMsg == true )
{
mDrawClickMsg = false;
- tqrepaint();
+ repaint();
}
TQLineEdit::focusInEvent( ev );
}
@@ -77,7 +77,7 @@ void ClickLineEdit::focusOutEvent( TQFocusEvent *ev )
if ( text().isEmpty() )
{
mDrawClickMsg = true;
- tqrepaint();
+ repaint();
}
TQLineEdit::focusOutEvent( ev );
}
diff --git a/kicker/kicker/ui/client_mnu.cpp b/kicker/kicker/ui/client_mnu.cpp
index deaae70b9..959726bfa 100644
--- a/kicker/kicker/ui/client_mnu.cpp
+++ b/kicker/kicker/ui/client_mnu.cpp
@@ -59,7 +59,7 @@ void KickerClientMenu::insertItem( TQString text, int id )
TQCString KickerClientMenu::insertMenu( TQPixmap icon, TQString text, int id )
{
TQString subname("%1-submenu%2");
- TQCString subid = subname.tqarg(static_cast<const char *>(objId())).tqarg(id).local8Bit();
+ TQCString subid = subname.arg(static_cast<const char *>(objId())).arg(id).local8Bit();
KickerClientMenu *sub = new KickerClientMenu(this, subid);
int globalid = TQPopupMenu::insertItem( icon, text, sub, id);
setItemParameter( globalid, id );
diff --git a/kicker/kicker/ui/exe_dlg.cpp b/kicker/kicker/ui/exe_dlg.cpp
index d39fb5942..6b1dd15ef 100644
--- a/kicker/kicker/ui/exe_dlg.cpp
+++ b/kicker/kicker/ui/exe_dlg.cpp
@@ -78,8 +78,8 @@ PanelExeDialog::PanelExeDialog(const TQString& title, const TQString& descriptio
this, TQT_SLOT(slotIconChanged(TQString)));
// leave decent space for the commandline
- resize(tqsizeHint().width() > 300 ? tqsizeHint().width() : 300,
- tqsizeHint().height());
+ resize(sizeHint().width() > 300 ? sizeHint().width() : 300,
+ sizeHint().height());
}
void PanelExeDialog::slotOk()
diff --git a/kicker/kicker/ui/extensionop_mnu.cpp b/kicker/kicker/ui/extensionop_mnu.cpp
index 582c44b46..a30434a48 100644
--- a/kicker/kicker/ui/extensionop_mnu.cpp
+++ b/kicker/kicker/ui/extensionop_mnu.cpp
@@ -59,7 +59,7 @@ PanelExtensionOpMenu::PanelExtensionOpMenu(const TQString& extension, int action
if (!Kicker::the()->isImmutable() && (actions & KPanelExtension::Preferences)) {
insertSeparator();
- insertItem(SmallIcon("configure"), i18n("&Configure %1...").tqarg(extension), Preferences);
+ insertItem(SmallIcon("configure"), i18n("&Configure %1...").arg(extension), Preferences);
}
adjustSize();
diff --git a/kicker/kicker/ui/flipscrollview.cpp b/kicker/kicker/ui/flipscrollview.cpp
index fb5cfd422..ae96ebcaa 100644
--- a/kicker/kicker/ui/flipscrollview.cpp
+++ b/kicker/kicker/ui/flipscrollview.cpp
@@ -57,7 +57,7 @@ void BackFrame::drawContents( TQPainter *p )
{
TQColor gray( 230, 230, 230 );
if ( mouse_inside )
- p->fillRect( 3, 3, width() - 6, height() - 6, tqcolorGroup().color( TQColorGroup::Highlight ) );
+ p->fillRect( 3, 3, width() - 6, height() - 6, colorGroup().color( TQColorGroup::Highlight ) );
else
p->fillRect( 3, 3, width() - 6, height() - 6, gray );
p->setPen( gray.dark(110) );
@@ -270,7 +270,7 @@ void FlipScrollView::slotScrollTimer()
if (!mSelectMenuPath.isEmpty()) {
if (mSelectMenuPath=="kicker:/goup/") {
currentView()->setSelected(currentView()->firstChild(),true);
- currentView()->firstChild()->tqrepaint();
+ currentView()->firstChild()->repaint();
}
else {
TQListViewItem * child = currentView()->firstChild();
@@ -278,8 +278,8 @@ void FlipScrollView::slotScrollTimer()
KMenuItem* kitem = dynamic_cast<KMenuItem*>(child);
if (kitem && kitem->menuPath()==mSelectMenuPath) {
currentView()->setSelected(child,true);
- kdDebug() << "child tqrepaint\n";
- child->tqrepaint();
+ kdDebug() << "child repaint\n";
+ child->repaint();
break;
}
child = child->nextSibling();
diff --git a/kicker/kicker/ui/hidebutton.cpp b/kicker/kicker/ui/hidebutton.cpp
index 58bde0457..25263e872 100644
--- a/kicker/kicker/ui/hidebutton.cpp
+++ b/kicker/kicker/ui/hidebutton.cpp
@@ -51,22 +51,22 @@ void HideButton::drawButton(TQPainter *p)
{
if (m_arrow == Qt::LeftArrow)
{
- p->setPen(tqcolorGroup().mid());
+ p->setPen(colorGroup().mid());
p->drawLine(width()-1, 0, width()-1, height());
}
else if (m_arrow == Qt::RightArrow)
{
- p->setPen(tqcolorGroup().mid());
+ p->setPen(colorGroup().mid());
p->drawLine(0, 0, 0, height());
}
else if (m_arrow == Qt::UpArrow)
{
- p->setPen(tqcolorGroup().mid());
+ p->setPen(colorGroup().mid());
p->drawLine(0, height()-1, width(), height()-1);
}
else if (m_arrow == Qt::DownArrow)
{
- p->setPen(tqcolorGroup().mid());
+ p->setPen(colorGroup().mid());
p->drawLine(0, 0, width(), 0);
}
@@ -173,14 +173,14 @@ void HideButton::slotIconChanged(int group)
}
generateIcons();
- tqrepaint(false);
+ repaint(false);
}
void HideButton::enterEvent(TQEvent *e)
{
m_highlight = true;
- tqrepaint(false);
+ repaint(false);
TQButton::enterEvent(e);
}
@@ -188,7 +188,7 @@ void HideButton::leaveEvent(TQEvent *e)
{
m_highlight = false;
- tqrepaint(false);
+ repaint(false);
TQButton::enterEvent(e);
}
diff --git a/kicker/kicker/ui/itemview.cpp b/kicker/kicker/ui/itemview.cpp
index f9ab06006..79a7430b5 100644
--- a/kicker/kicker/ui/itemview.cpp
+++ b/kicker/kicker/ui/itemview.cpp
@@ -31,7 +31,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#include <tqpainter.h>
#include <tqstyle.h>
#include <tqwidgetstack.h>
-#include <tqlayout.h>
+#include <layout.h>
#include <tqlabel.h>
#include <tqvbox.h>
#include <tqheader.h>
@@ -41,7 +41,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#include <tqpaintdevicemetrics.h>
#include <tqbuffer.h>
#include <tqtooltip.h>
-#include <tqstylesheet.h>
+#include <stylesheet.h>
#include <tqiconview.h>
#include <dcopclient.h>
@@ -145,7 +145,7 @@ void KMenuItem::setIcon(const TQString& icon, int size)
void KMenuItem::setHasChildren( bool flag )
{
m_has_children = flag;
- tqrepaint();
+ repaint();
}
void KMenuItem::setup()
@@ -166,7 +166,7 @@ void KMenuItem::setup()
void KMenuItem::paintCell(TQPainter* p, const TQColorGroup & cg, int column, int width, int align)
{
ItemView *listview = static_cast<ItemView*>( listView() );
- int bottom = listView()->tqitemRect( this ).bottom();
+ int bottom = listView()->itemRect( this ).bottom();
int diff = bottom - listView()->viewport()->height();
KPixmap pm;
@@ -197,7 +197,7 @@ void KMenuItem::paintCell(TQPainter* p, const TQColorGroup & cg, int column, int
else
listview->m_lastOne = static_cast<KMenuItem*>( itemBelow() );
listview->m_old_contentY = -1;
- tqrepaint();
+ repaint();
}
}
}
@@ -350,7 +350,7 @@ void KMenuItem::paintCellInter(TQPainter* p, const TQColorGroup & cg, int column
{
// the listview caches paint events
m_old_width = width;
- tqrepaint();
+ repaint();
}
}
@@ -608,7 +608,7 @@ void ItemViewTip::maybeTip( const TQPoint &pos )
if ( item->toolTip().isNull() )
return;
- TQRect r = view->tqitemRect( item );
+ TQRect r = view->itemRect( item );
int headerPos = view->header()->sectionPos( 0 );
r.setLeft( headerPos );
r.setRight( headerPos + view->header()->sectionSize( 0 ) );
@@ -915,7 +915,7 @@ void ItemView::contentsMousePressEvent ( TQMouseEvent * e )
KMenuItemSeparator *si = dynamic_cast<KMenuItemSeparator*>( itemAt( vp ) );
if ( si )
{
- if ( si->hitsLink( vp - tqitemRect(si).topLeft() ) )
+ if ( si->hitsLink( vp - itemRect(si).topLeft() ) )
emit startURL( si->linkUrl() );
}
}
@@ -928,7 +928,7 @@ void ItemView::contentsMouseMoveEvent(TQMouseEvent *e)
bool link_cursor = false;
KMenuItemSeparator *si = dynamic_cast<KMenuItemSeparator*>( i );
if ( si )
- link_cursor = si->hitsLink( vp - tqitemRect(si).topLeft() );
+ link_cursor = si->hitsLink( vp - itemRect(si).topLeft() );
if (i && !i->isSelectable() && !link_cursor) {
unsetCursor();
@@ -965,7 +965,7 @@ void ItemView::resizeEvent ( TQResizeEvent * e )
{
KListView::resizeEvent( e );
// if ( m_lastOne )
-// int diff = tqitemRect( m_lastOne ).bottom() - viewport()->height();
+// int diff = itemRect( m_lastOne ).bottom() - viewport()->height();
}
void ItemView::viewportPaintEvent ( TQPaintEvent * pe )
@@ -975,7 +975,7 @@ void ItemView::viewportPaintEvent ( TQPaintEvent * pe )
if ( m_lastOne && m_old_contentY != contentsY() ) {
m_old_contentY = contentsY();
- m_lastOne->tqrepaint();
+ m_lastOne->repaint();
}
}
@@ -1052,7 +1052,7 @@ TQDragObject * ItemView::dragObject()
else if(!kitem->path().isEmpty() && !kitem->path().startsWith("kicker:/") && !kitem->path().startsWith("kaddressbook:/")) {
TQString uri = kitem->path();
- if (uri.startsWith(locateLocal("data", TQString::tqfromLatin1("RecentDocuments/")))) {
+ if (uri.startsWith(locateLocal("data", TQString::fromLatin1("RecentDocuments/")))) {
KDesktopFile df(uri,true);
uri=df.readURL();
}
@@ -1103,7 +1103,7 @@ const char * KMenuItemDrag::format(int i) const
return 0;
}
-TQByteArray KMenuItemDrag::tqencodedData(const char* mimeType) const
+TQByteArray KMenuItemDrag::encodedData(const char* mimeType) const
{
if (TQString("application/kmenuitem") == mimeType)
return a;
@@ -1138,7 +1138,7 @@ bool ItemView::acceptDrag (TQDropEvent* event) const
bool KMenuItemDrag::decode(const TQMimeSource* e, KMenuItemInfo& item)
{
- TQByteArray a = e->tqencodedData("application/kmenuitem");
+ TQByteArray a = e->encodedData("application/kmenuitem");
if (a.isEmpty()) {
TQStringList l;
@@ -1211,7 +1211,7 @@ bool FavoritesItemView::acceptDrag (TQDropEvent* event) const
TQString uri = item.m_path;
- if (uri.startsWith(locateLocal("data", TQString::tqfromLatin1("RecentDocuments/")))) {
+ if (uri.startsWith(locateLocal("data", TQString::fromLatin1("RecentDocuments/")))) {
KDesktopFile df(uri,true);
uri=df.readURL();
}
diff --git a/kicker/kicker/ui/itemview.h b/kicker/kicker/ui/itemview.h
index 2a6b7e68b..c8b95ee42 100644
--- a/kicker/kicker/ui/itemview.h
+++ b/kicker/kicker/ui/itemview.h
@@ -248,7 +248,7 @@ class KMenuItemDrag : public TQDragObject
~KMenuItemDrag();
virtual const char * format(int i = 0) const;
- virtual TQByteArray tqencodedData(const char *) const;
+ virtual TQByteArray encodedData(const char *) const;
static bool canDecode(const TQMimeSource * e);
static bool decode(const TQMimeSource* e, KMenuItemInfo& item);
diff --git a/kicker/kicker/ui/k_mnu.h b/kicker/kicker/ui/k_mnu.h
index f7ad2ee77..53a29d809 100644
--- a/kicker/kicker/ui/k_mnu.h
+++ b/kicker/kicker/ui/k_mnu.h
@@ -59,7 +59,7 @@ public:
int insertClientMenu(KickerClientMenu *p);
void removeClientMenu(int id);
- virtual TQSize tqsizeHint() const;
+ virtual TQSize sizeHint() const;
virtual void setMinimumSize(const TQSize &);
virtual void setMaximumSize(const TQSize &);
virtual void setMinimumSize(int, int);
diff --git a/kicker/kicker/ui/k_mnu_stub.cpp b/kicker/kicker/ui/k_mnu_stub.cpp
index 16e755d48..b02d2bcbf 100644
--- a/kicker/kicker/ui/k_mnu_stub.cpp
+++ b/kicker/kicker/ui/k_mnu_stub.cpp
@@ -97,11 +97,11 @@ void KMenuStub::resize(int w, int h)
return m_w.panelkmenu->resize(w, h);
}
-TQSize KMenuStub::tqsizeHint() const
+TQSize KMenuStub::sizeHint() const
{
if(m_type == t_KMenu)
- return m_w.kmenu->tqsizeHint();
- return m_w.panelkmenu->tqsizeHint();
+ return m_w.kmenu->sizeHint();
+ return m_w.panelkmenu->sizeHint();
}
bool KMenuStub::highlightMenuItem( const TQString &menuId )
diff --git a/kicker/kicker/ui/k_mnu_stub.h b/kicker/kicker/ui/k_mnu_stub.h
index 17fe92b7c..362d132b2 100644
--- a/kicker/kicker/ui/k_mnu_stub.h
+++ b/kicker/kicker/ui/k_mnu_stub.h
@@ -53,7 +53,7 @@ public:
void popup(const TQPoint &pos, int indexAtPoint = -1);
void selectFirstItem();
void resize(int, int);
- TQSize tqsizeHint() const;
+ TQSize sizeHint() const;
bool highlightMenuItem( const TQString &menuId );
void clearRecentMenuItems();
void initialize();
diff --git a/kicker/kicker/ui/k_new_mnu.cpp b/kicker/kicker/ui/k_new_mnu.cpp
index e27f47d88..2725d3de1 100644
--- a/kicker/kicker/ui/k_new_mnu.cpp
+++ b/kicker/kicker/ui/k_new_mnu.cpp
@@ -31,11 +31,11 @@
#include <tqpainter.h>
#include <tqstyle.h>
#include <tqwidgetstack.h>
-#include <tqlayout.h>
+#include <layout.h>
#include <tqlabel.h>
#include <tqregexp.h>
#include <tqfile.h>
-#include <tqstylesheet.h>
+#include <stylesheet.h>
#include <tqaccel.h>
#include <tqcursor.h>
#include <tqdir.h>
@@ -302,7 +302,7 @@ KMenu::KMenu()
m_searchInternet->setPixmap(0,icon);
setTabOrder(m_kcommand, m_searchResultsWidget);
- m_kerryInstalled = !KStandardDirs::findExe(TQString::tqfromLatin1("kerry")).isEmpty();
+ m_kerryInstalled = !KStandardDirs::findExe(TQString::fromLatin1("kerry")).isEmpty();
m_isShowing = false;
if (!m_kerryInstalled) {
@@ -421,7 +421,7 @@ void KMenu::setupUi()
{
m_stacker = new TQWidgetStack( this, "m_stacker" );
m_stacker->setGeometry( TQRect( 90, 260, 320, 220 ) );
- m_stacker->tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)3, (TQSizePolicy::SizeType)3, 1, 1, m_stacker->sizePolicy().hasHeightForWidth() ) );
+ m_stacker->setSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)3, (TQSizePolicy::SizeType)3, 1, 1, m_stacker->sizePolicy().hasHeightForWidth() ) );
m_stacker->setPaletteBackgroundColor( TQColor( 255, 255, 255 ) );
// m_stacker->setFocusPolicy( TQ_StrongFocus );
m_stacker->setLineWidth( 0 );
@@ -522,7 +522,7 @@ bool KMenu::eventFilter ( TQObject * receiver, TQEvent* e)
m_sloppySourceClicked = true;
if (!m_sloppyTimer.isActive() || m_sloppySource != raiseRect) {
- int timeout= tqstyle().tqstyleHint(TQStyle::SH_PopupMenu_SubMenuPopupDelay);
+ int timeout= tqstyle().styleHint(TQStyle::SH_PopupMenu_SubMenuPopupDelay);
if (m_sloppySourceClicked)
timeout = 3000;
m_sloppyTimer.start(timeout);
@@ -1131,7 +1131,7 @@ void KMenu::fillMenu(KServiceGroup::Ptr&
}
// Ignore dotfiles.
- if ((g->name().tqat(0) == '.'))
+ if ((g->name().at(0) == '.'))
{
continue;
}
@@ -1699,14 +1699,14 @@ void KMenu::setOrientation(MenuOrientation orientation)
TQWidget *footer = m_footer->mainWidget();
TQPixmap pix( 64, footer->height() );
TQPainter p( &pix );
- p.fillRect( 0, 0, 64, footer->height(), m_branding->tqcolorGroup().brush( TQColorGroup::Base ) );
+ p.fillRect( 0, 0, 64, footer->height(), m_branding->colorGroup().brush( TQColorGroup::Base ) );
p.fillRect( 0, m_orientation == BottomUp ? footer->height() - 2 : 0,
64, 3, KNewButton::self()->borderColor() );
p.end();
footer->setPaletteBackgroundPixmap( pix );
}
- resizeEvent(new TQResizeEvent(tqsizeHint(), tqsizeHint()));
+ resizeEvent(new TQResizeEvent(sizeHint(), sizeHint()));
}
void KMenu::showMenu()
@@ -1762,7 +1762,7 @@ void KMenu::paintEvent(TQPaintEvent * e)
const BackgroundMode bgmode = backgroundMode();
const TQColorGroup::ColorRole crole = TQPalette::backgroundRoleFromMode( bgmode );
- p.setBrush( tqcolorGroup().brush( crole ) );
+ p.setBrush( colorGroup().brush( crole ) );
p.drawRect( 0, 0, width(), height() );
int ypos = m_search->mainWidget()->geometry().bottom();
@@ -1923,7 +1923,7 @@ void KMenu::createNewProgramList()
m_seenPrograms = KickerSettings::firstSeenApps();
m_newInstalledPrograms.clear();
- m_tqcurrentDate = TQDate::currentDate().toString(Qt::ISODate);
+ m_currentDate = TQDate::currentDate().toString(Qt::ISODate);
bool initialize = (m_seenPrograms.count() == 0);
@@ -1978,7 +1978,7 @@ void KMenu::createNewProgramList(TQString relPath)
if (!found) {
m_seenProgramsChanged=true;
m_seenPrograms+=shortStorageId;
- m_seenPrograms+=m_tqcurrentDate;
+ m_seenPrograms+=m_currentDate;
if (m_newInstalledPrograms.find(s->storageId())==m_newInstalledPrograms.end())
m_newInstalledPrograms+=s->storageId();
}
@@ -2744,7 +2744,7 @@ void KMenu::slotContextMenuRequested( TQListViewItem * item, const TQPoint & pos
m_popupPath.path = kitem->path();
m_popupPath.icon = kitem->icon();
- if (m_popupPath.path.startsWith(locateLocal("data", TQString::tqfromLatin1("RecentDocuments/")))) {
+ if (m_popupPath.path.startsWith(locateLocal("data", TQString::fromLatin1("RecentDocuments/")))) {
KDesktopFile df(m_popupPath.path,true);
m_popupPath.path=df.readURL();
}
@@ -2936,7 +2936,7 @@ void KMenu::slotContextMenu(int selected)
case EditMenu:
accept();
proc = new KProcess(TQT_TQOBJECT(this));
- *proc << KStandardDirs::findExe(TQString::tqfromLatin1("kmenuedit"));
+ *proc << KStandardDirs::findExe(TQString::fromLatin1("kmenuedit"));
*proc << "/"+m_popupPath.menuPath.section('/',-200,-2) << m_popupPath.menuPath.section('/', -1);
proc->start();
break;
@@ -3074,24 +3074,24 @@ void KMenu::resizeEvent ( TQResizeEvent * e )
// put the search widget at the top of the menu and give it its desired
// height
m_search->mainWidget()->setGeometry( 0, ypos, width(),
- m_search->tqminimumSize().height() );
- left_height -= m_search->tqminimumSize().height();
- ypos += m_search->tqminimumSize().height();
+ m_search->minimumSize().height() );
+ left_height -= m_search->minimumSize().height();
+ ypos += m_search->minimumSize().height();
// place the footer widget at the bottom of the menu and give it its desired
// height
- m_footer->mainWidget()->setGeometry( 0, height() - m_footer->tqminimumSize().height(),
- width(), m_footer->tqminimumSize().height() );
- left_height -= m_footer->tqminimumSize().height();
+ m_footer->mainWidget()->setGeometry( 0, height() - m_footer->minimumSize().height(),
+ width(), m_footer->minimumSize().height() );
+ left_height -= m_footer->minimumSize().height();
// place the button box above the footer widget, horizontal placement
// has the width of the edge graphics subtracted
m_tabBar->setGeometry(button_box_left.width(),
- height() - m_footer->tqminimumSize().height() -
- m_tabBar->tqsizeHint().height(),
+ height() - m_footer->minimumSize().height() -
+ m_tabBar->sizeHint().height(),
width() - button_box_left.width(),
- m_tabBar->tqsizeHint().height() );
- left_height -= m_tabBar->tqsizeHint().height();
+ m_tabBar->sizeHint().height() );
+ left_height -= m_tabBar->sizeHint().height();
// place the main (stacker) widget below the search widget,
// in the remaining vertical space
@@ -3105,28 +3105,28 @@ void KMenu::resizeEvent ( TQResizeEvent * e )
// place the 'footer' widget at the top of the menu and give it
// its desired height
m_footer->mainWidget()->setGeometry( 0,
- ypos /*height() - m_footer->tqminimumSize().height()*/,
+ ypos /*height() - m_footer->minimumSize().height()*/,
width(),
- m_footer->tqminimumSize().height() );
- ypos += m_footer->tqminimumSize().height();
- left_height -= m_footer->tqminimumSize().height();
+ m_footer->minimumSize().height() );
+ ypos += m_footer->minimumSize().height();
+ left_height -= m_footer->minimumSize().height();
// place the button box next at the top of the menu.
// has the width of the edge graphics subtracted
m_tabBar->setGeometry(button_box_left.width(), ypos, width() - button_box_left.width(),
- m_tabBar->tqsizeHint().height());
+ m_tabBar->sizeHint().height());
- ypos += m_tabBar->tqsizeHint().height();
- left_height -= m_tabBar->tqsizeHint().height();
+ ypos += m_tabBar->sizeHint().height();
+ left_height -= m_tabBar->sizeHint().height();
// put the search widget above the footer widget
// height
m_search->mainWidget()->setGeometry( 0,
- height() - m_search->tqminimumSize().height(),
+ height() - m_search->minimumSize().height(),
width(),
- m_search->tqminimumSize().height()
+ m_search->minimumSize().height()
);
- left_height -= m_search->tqminimumSize().height();
+ left_height -= m_search->minimumSize().height();
// place the main (stacker) widget below the button box,
// in the remaining vertical space
@@ -3167,14 +3167,14 @@ void KMenu::mouseMoveEvent ( TQMouseEvent * e )
if ( hasMouseTracking() && m_isresizing ) {
m_stacker->setMinimumSize( TQSize(0, 0) );
m_stacker->setMaximumSize( TQSize(32000, 32000) );
- int newWidth = QMAX( e->x() - x(), tqminimumSizeHint().width() );
+ int newWidth = QMAX( e->x() - x(), minimumSizeHint().width() );
if ( m_orientation == BottomUp ) {
- int newHeight = QMAX( height() - e->y(), tqminimumSizeHint().height() + 10 );
+ int newHeight = QMAX( height() - e->y(), minimumSizeHint().height() + 10 );
int newY = y() + height() - newHeight;
setGeometry( x(), newY, newWidth, newHeight);
}
else {
- setGeometry( x(), y(), newWidth, QMAX( e->y(), tqminimumSizeHint().height() + 10 ));
+ setGeometry( x(), y(), newWidth, QMAX( e->y(), minimumSizeHint().height() + 10 ));
}
}
}
@@ -3331,7 +3331,7 @@ void KMenu::updateRecentlyUsedApps(KService::Ptr &service)
RecentlyLaunchedApps::the().m_bNeedToUpdate = true;
}
-TQSize KMenu::tqsizeHint() const
+TQSize KMenu::sizeHint() const
{
#warning FIXME
// this should be only for the inner area so layout changes do not break it
@@ -3339,28 +3339,28 @@ TQSize KMenu::tqsizeHint() const
const int height = kMin(KickerSettings::kMenuHeight(), TQApplication::desktop()->screen()->height()-50);
TQSize wanted(width, height);
- kdDebug() << "show " << tqminimumSizeHint() << " " << m_stacker->tqminimumSizeHint() << " "
- << m_searchFrame->tqminimumSizeHint() << " " << wanted << endl;
+ kdDebug() << "show " << minimumSizeHint() << " " << m_stacker->minimumSizeHint() << " "
+ << m_searchFrame->minimumSizeHint() << " " << wanted << endl;
bool isDefault = wanted.isNull();
- wanted = wanted.expandedTo(tqminimumSizeHint());
+ wanted = wanted.expandedTo(minimumSizeHint());
if ( isDefault )
- wanted.setHeight( wanted.height() + ( m_favoriteView->goodHeight() - m_stacker->tqminimumSizeHint().height() ) );
+ wanted.setHeight( wanted.height() + ( m_favoriteView->goodHeight() - m_stacker->minimumSizeHint().height() ) );
return wanted;
}
-TQSize KMenu::tqminimumSizeHint() const
+TQSize KMenu::minimumSizeHint() const
{
TQSize minsize;
- minsize.setWidth( minsize.width() + m_tabBar->tqsizeHint().width() );
+ minsize.setWidth( minsize.width() + m_tabBar->sizeHint().width() );
minsize.setWidth( QMAX( minsize.width(),
- m_search->tqminimumSize().width() ) );
+ m_search->minimumSize().width() ) );
minsize.setWidth( QMAX( minsize.width(),
- m_search->tqminimumSize().width() ) );
+ m_search->minimumSize().width() ) );
minsize.setHeight( minsize.height() +
- m_search->tqminimumSize().height() +
- m_footer->tqminimumSize().height() +
+ m_search->minimumSize().height() +
+ m_footer->minimumSize().height() +
180 ); // 180 is a very rough guess for 32 icon size
return minsize;
}
@@ -3558,7 +3558,7 @@ void KMenu::slotFavDropped(TQDropEvent * ev, TQListViewItem *after )
else
{
TQString uri = item.m_path;
- if (uri.startsWith(locateLocal("data", TQString::tqfromLatin1("RecentDocuments/")))) {
+ if (uri.startsWith(locateLocal("data", TQString::fromLatin1("RecentDocuments/")))) {
KDesktopFile df(uri,true);
uri=df.readURL();
}
@@ -3625,7 +3625,7 @@ void KMenu::slotFavDropped(TQDropEvent * ev, TQListViewItem *after )
df.writeEntry("Encoding", "UTF-8");
df.writeEntry("Type","Link");
df.writeEntry("Name", item->name());
- df.writeEntry("GenericName", i18n("Directory: %1").tqarg(kurl.upURL().path()));
+ df.writeEntry("GenericName", i18n("Directory: %1").arg(kurl.upURL().path()));
df.writeEntry("Icon", item->iconName());
df.writeEntry("URL", text);
diff --git a/kicker/kicker/ui/k_new_mnu.h b/kicker/kicker/ui/k_new_mnu.h
index 73549cfa0..ef45ef815 100644
--- a/kicker/kicker/ui/k_new_mnu.h
+++ b/kicker/kicker/ui/k_new_mnu.h
@@ -104,8 +104,8 @@ public:
enum MaskEffect { Plain, Dissolve };
- virtual TQSize tqsizeHint() const;
- virtual TQSize tqminimumSizeHint() const;
+ virtual TQSize sizeHint() const;
+ virtual TQSize minimumSizeHint() const;
void searchOver();
void initCategoryTitlesUpdate();
@@ -319,7 +319,7 @@ private:
TQStringList m_programsInMenu;
TQStringList m_newInstalledPrograms, m_seenPrograms;
bool m_seenProgramsChanged;
- TQString m_tqcurrentDate;
+ TQString m_currentDate;
MenuOrientation m_orientation;
bool m_toolTipsEnabled;
diff --git a/kicker/kicker/ui/kickoff_bar.cpp b/kicker/kicker/ui/kickoff_bar.cpp
index 6a41a719b..3c6b68bc2 100644
--- a/kicker/kicker/ui/kickoff_bar.cpp
+++ b/kicker/kicker/ui/kickoff_bar.cpp
@@ -58,8 +58,8 @@ void KickoffTabBar::paint(TQPainter* p, TQTab* t, bool selected) const
//selection flags
if(t->rect().contains(mapFromGlobal(TQCursor::pos())))
flags |= TQStyle::Style_MouseOver;
- tqstyle().tqdrawControl( TQStyle::CE_TabBarTab, p, this, t->rect(),
- tqcolorGroup(), flags, TQStyleOption(t) );
+ tqstyle().drawControl( TQStyle::CE_TabBarTab, p, this, t->rect(),
+ colorGroup(), flags, TQStyleOption(t) );
paintLabel( p, t->rect(), t, t->identifier() == keyboardFocusTab() );
}
@@ -70,7 +70,7 @@ void KickoffTabBar::paintLabel(TQPainter* p, const TQRect& br, TQTab* t, bool ha
TQRect r = br;
bool selected = m_tabsActivated && (currentTab() == t->identifier());
- int vframe = tqstyle().tqpixelMetric( TQStyle::PM_TabBarTabVSpace, this );
+ int vframe = tqstyle().pixelMetric( TQStyle::PM_TabBarTabVSpace, this );
p->setFont( font() );
TQFontMetrics fm = p->fontMetrics();
@@ -116,14 +116,14 @@ void KickoffTabBar::paintLabel(TQPainter* p, const TQRect& br, TQTab* t, bool ha
// flags |= TQStyle::Style_Sunken;
if(t->rect().contains(mapFromGlobal(TQCursor::pos())))
flags |= TQStyle::Style_MouseOver;
- tqstyle().tqdrawControl( TQStyle::CE_TabBarLabel, p, this, rt,
- t->isEnabled() ? tqcolorGroup(): tqpalette().disabled(),
+ tqstyle().drawControl( TQStyle::CE_TabBarLabel, p, this, rt,
+ t->isEnabled() ? colorGroup(): palette().disabled(),
flags, TQStyleOption(t) );
}
-TQSize KickoffTabBar::tqsizeHint() const
+TQSize KickoffTabBar::sizeHint() const
{
- TQSize s = TQTabBar::tqsizeHint();
+ TQSize s = TQTabBar::sizeHint();
return s;
}
@@ -135,9 +135,9 @@ void KickoffTabBar::layoutTabs()
TQFontMetrics fm = fontMetrics();
int fh = ((KickerSettings::kickoffTabBarFormat() != KickerSettings::IconOnly) ? fm.height() : 0) + 4;
- int hframe = tqstyle().tqpixelMetric( TQStyle::PM_TabBarTabHSpace, this );
- int vframe = tqstyle().tqpixelMetric( TQStyle::PM_TabBarTabVSpace, this );
- int overlap = tqstyle().tqpixelMetric( TQStyle::PM_TabBarTabOverlap, this );
+ int hframe = tqstyle().pixelMetric( TQStyle::PM_TabBarTabHSpace, this );
+ int vframe = tqstyle().pixelMetric( TQStyle::PM_TabBarTabVSpace, this );
+ int overlap = tqstyle().pixelMetric( TQStyle::PM_TabBarTabOverlap, this );
TQSize s;
for (int t = 0; t < count(); ++t)
diff --git a/kicker/kicker/ui/kickoff_bar.h b/kicker/kicker/ui/kickoff_bar.h
index 55f94c3dd..2330ffe39 100644
--- a/kicker/kicker/ui/kickoff_bar.h
+++ b/kicker/kicker/ui/kickoff_bar.h
@@ -32,7 +32,7 @@ public:
KickoffTabBar(TQWidget* parent, const char* name);
void deactivateTabs(bool b);
- virtual TQSize tqsizeHint() const;
+ virtual TQSize sizeHint() const;
protected:
virtual void paint(TQPainter*, TQTab*, bool) const;
diff --git a/kicker/kicker/ui/kmenuitembase.ui b/kicker/kicker/ui/kmenuitembase.ui
index 0b49763a1..ee4f26ffa 100644
--- a/kicker/kicker/ui/kmenuitembase.ui
+++ b/kicker/kicker/ui/kmenuitembase.ui
@@ -20,13 +20,13 @@
<verstretch>0</verstretch>
</sizepolicy>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>0</width>
<height>0</height>
</size>
</property>
- <property name="tqmaximumSize">
+ <property name="maximumSize">
<size>
<width>32767</width>
<height>80</height>
@@ -73,7 +73,7 @@
<property name="textFormat">
<enum>RichText</enum>
</property>
- <property name="tqalignment">
+ <property name="alignment">
<set>WordBreak|AlignTop</set>
</property>
</widget>
@@ -102,7 +102,7 @@
<property name="textFormat">
<enum>RichText</enum>
</property>
- <property name="tqalignment">
+ <property name="alignment">
<set>WordBreak|AlignTop</set>
</property>
</widget>
@@ -120,7 +120,7 @@
<property name="name">
<cstring>itemPixmap</cstring>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>64</width>
<height>64</height>
@@ -129,7 +129,7 @@
<property name="text">
<string></string>
</property>
- <property name="tqalignment">
+ <property name="alignment">
<set>AlignTop|AlignHCenter</set>
</property>
</widget>
diff --git a/kicker/kicker/ui/nonKDEButtonSettings.ui b/kicker/kicker/ui/nonKDEButtonSettings.ui
index a3f04e6a8..187dd7cb5 100644
--- a/kicker/kicker/ui/nonKDEButtonSettings.ui
+++ b/kicker/kicker/ui/nonKDEButtonSettings.ui
@@ -121,7 +121,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>16</height>
@@ -140,13 +140,13 @@
<verstretch>0</verstretch>
</sizepolicy>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>58</width>
<height>58</height>
</size>
</property>
- <property name="tqmaximumSize">
+ <property name="maximumSize">
<size>
<width>58</width>
<height>58</height>
@@ -199,7 +199,7 @@
<property name="sizeType">
<enum>Minimum</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>8</height>
diff --git a/kicker/kicker/ui/popupmenutitle.h b/kicker/kicker/ui/popupmenutitle.h
index c9e545417..1e15179f7 100644
--- a/kicker/kicker/ui/popupmenutitle.h
+++ b/kicker/kicker/ui/popupmenutitle.h
@@ -69,11 +69,11 @@ public:
m_font.setBold(true);
}
- TQSize tqsizeHint()
+ TQSize sizeHint()
{
TQSize size = TQFontMetrics(m_font).size(AlignHCenter, m_desktopName);
size.setHeight(size.height() +
- (kapp->tqstyle().tqpixelMetric(TQStyle::PM_DefaultFrameWidth) * 2 + 1));
+ (kapp->tqstyle().pixelMetric(TQStyle::PM_DefaultFrameWidth) * 2 + 1));
return size;
}
diff --git a/kicker/kicker/ui/removeapplet_mnu.cpp b/kicker/kicker/ui/removeapplet_mnu.cpp
index 8dfaa00d2..2e0543dae 100644
--- a/kicker/kicker/ui/removeapplet_mnu.cpp
+++ b/kicker/kicker/ui/removeapplet_mnu.cpp
@@ -87,9 +87,9 @@ void PanelRemoveAppletMenu::slotAboutToShow()
void PanelRemoveAppletMenu::slotExec(int id)
{
- if (m_containers.tqat(id) != m_containers.end())
+ if (m_containers.at(id) != m_containers.end())
{
- m_containerArea->removeContainer(*m_containers.tqat(id));
+ m_containerArea->removeContainer(*m_containers.at(id));
}
}
diff --git a/kicker/kicker/ui/removebutton_mnu.cpp b/kicker/kicker/ui/removebutton_mnu.cpp
index 678d6a78f..8f02abd67 100644
--- a/kicker/kicker/ui/removebutton_mnu.cpp
+++ b/kicker/kicker/ui/removebutton_mnu.cpp
@@ -95,9 +95,9 @@ void PanelRemoveButtonMenu::slotAboutToShow()
void PanelRemoveButtonMenu::slotExec( int id )
{
- if (containers.tqat(id) != containers.end())
+ if (containers.at(id) != containers.end())
{
- containerArea->removeContainer(*containers.tqat(id));
+ containerArea->removeContainer(*containers.at(id));
}
}
diff --git a/kicker/kicker/ui/removeextension_mnu.cpp b/kicker/kicker/ui/removeextension_mnu.cpp
index 9a1655bae..9d5d80d2b 100644
--- a/kicker/kicker/ui/removeextension_mnu.cpp
+++ b/kicker/kicker/ui/removeextension_mnu.cpp
@@ -100,9 +100,9 @@ void PanelRemoveExtensionMenu::slotExec( int id )
{
ExtensionManager::the()->removeAllContainers();
}
- else if (m_containers.tqat(id) != m_containers.end())
+ else if (m_containers.at(id) != m_containers.end())
{
- ExtensionManager::the()->removeContainer(*m_containers.tqat(id));
+ ExtensionManager::the()->removeContainer(*m_containers.at(id));
}
}
diff --git a/kicker/kicker/ui/service_mnu.cpp b/kicker/kicker/ui/service_mnu.cpp
index ee0414644..8dcc2fbde 100644
--- a/kicker/kicker/ui/service_mnu.cpp
+++ b/kicker/kicker/ui/service_mnu.cpp
@@ -281,7 +281,7 @@ void PanelServiceMenu::fillMenu(KServiceGroup::Ptr& _root,
}
// Ignore dotfiles.
- if ((g->name().tqat(0) == '.'))
+ if ((g->name().at(0) == '.'))
{
continue;
}
@@ -445,7 +445,7 @@ void PanelServiceMenu::insertMenuItem(KService::Ptr & s, int nId,
return;
// ignore dotfiles.
- if ((serviceName.tqat(0) == '.'))
+ if ((serviceName.at(0) == '.'))
return;
// item names may contain ampersands. To avoid them being converted
@@ -695,7 +695,7 @@ void PanelServiceMenu::slotContextMenu(int selected)
case EditItem:
proc = new KProcess(TQT_TQOBJECT(this));
- *proc << KStandardDirs::findExe(TQString::tqfromLatin1("kmenuedit"));
+ *proc << KStandardDirs::findExe(TQString::fromLatin1("kmenuedit"));
*proc << "/"+relPath_ << static_cast<KService *>(contextKSycocaEntry_)->menuId();
proc->start();
break;
@@ -739,7 +739,7 @@ void PanelServiceMenu::slotContextMenu(int selected)
case EditMenu:
proc = new KProcess(TQT_TQOBJECT(this));
- *proc << KStandardDirs::findExe(TQString::tqfromLatin1("kmenuedit"));
+ *proc << KStandardDirs::findExe(TQString::fromLatin1("kmenuedit"));
*proc << "/"+static_cast<KServiceGroup *>(contextKSycocaEntry_)->relPath();
proc->start();
break;
diff --git a/kicker/kicker/ui/k_mnu.cpp b/kicker/kicker/ui/k_mnu.cpp
index 6953143c9..a78971927 100644
--- a/kicker/kicker/ui/k_mnu.cpp
+++ b/kicker/kicker/ui/k_mnu.cpp
@@ -211,7 +211,7 @@ void PanelKMenu::paletteChanged()
if (!loadSidePixmap())
{
sidePixmap = sideTilePixmap = TQPixmap();
- setMinimumSize( tqsizeHint() );
+ setMinimumSize( sizeHint() );
}
}
@@ -348,7 +348,7 @@ void PanelKMenu::initialize()
if (clients.count() > 0) {
TQIntDictIterator<KickerClientMenu> it(clients);
while (it){
- if (it.current()->text.tqat(0) != '.')
+ if (it.current()->text.at(0) != '.')
insertItem(
it.current()->icon,
it.current()->text,
@@ -419,10 +419,10 @@ void PanelKMenu::repairDisplay(void) {
displayRepairTimer->stop();
// Now do a nasty hack to prevent search bar merging into the side image
- // This forces a layout/tqrepaint of the qpopupmenu
- tqrepaint(); // This ensures that the side bar image was applied
+ // This forces a layout/repaint of the qpopupmenu
+ repaint(); // This ensures that the side bar image was applied
styleChange(tqstyle()); // This forces a call to the private function updateSize(TRUE) inside the qpopupmenu.
- update(); // This repaints the entire popup menu to apply the widget size/tqalignment changes made above
+ update(); // This repaints the entire popup menu to apply the widget size/alignment changes made above
}
}
@@ -584,7 +584,7 @@ void PanelKMenu::showMenu()
TQRect PanelKMenu::sideImageRect()
{
- return TQStyle::tqvisualRect( TQRect( frameWidth(), frameWidth(), sidePixmap.width(),
+ return TQStyle::visualRect( TQRect( frameWidth(), frameWidth(), sidePixmap.width(),
height() - 2*frameWidth() ), this );
}
@@ -595,21 +595,21 @@ void PanelKMenu::resizeEvent(TQResizeEvent * e)
PanelServiceMenu::resizeEvent(e);
- setFrameRect( TQStyle::tqvisualRect( TQRect( sidePixmap.width(), 0,
+ setFrameRect( TQStyle::visualRect( TQRect( sidePixmap.width(), 0,
width() - sidePixmap.width(), height() ), this ) );
}
//Workaround Qt3.3.x sizing bug, by ensuring we're always wide enough.
void PanelKMenu::resize(int width, int height)
{
- width = kMax(width, tqmaximumSize().width());
+ width = kMax(width, maximumSize().width());
PanelServiceMenu::resize(width, height);
}
-TQSize PanelKMenu::tqsizeHint() const
+TQSize PanelKMenu::sizeHint() const
{
- TQSize s = PanelServiceMenu::tqsizeHint();
-// kdDebug(1210) << "PanelKMenu::tqsizeHint()" << endl;
+ TQSize s = PanelServiceMenu::sizeHint();
+// kdDebug(1210) << "PanelKMenu::sizeHint()" << endl;
// kdDebug(1210) << s.width() << ", " << s.height() << endl;
return s;
}
@@ -626,7 +626,7 @@ void PanelKMenu::paintEvent(TQPaintEvent * e)
tqstyle().tqdrawPrimitive( TQStyle::PE_PanelPopup, &p,
TQRect( 0, 0, width(), height() ),
- tqcolorGroup(), TQStyle::Style_Default,
+ colorGroup(), TQStyle::Style_Default,
TQStyleOption( frameWidth(), 0 ) );
TQRect r = sideImageRect();